@@ -5,8 +5,9 @@ use warnings;
 use HTML::Template;
 use Devel::StackTrace;
 use IO::File;
+use UNIVERSAL::require;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 our $A_HEAD = '<a class="package" href="?rm=view_code&amp;module=';
 our $A_TAIL = ';view_code_no_popup=1">';
@@ -144,6 +145,15 @@ sub import {
         }
         $self->report(@_);
     });
+
+    if ( ! exists $INC{'CGI/Application/Dispatch.pm'} &&
+         ! exists $INC{'CGI/Application/Plugin/ViewCode.pm'}
+       )
+    {
+        "CGI::Application::Plugin::ViewCode"->require
+         or delete $INC{'CGI/Application/Plugin/ViewCode.pm'};
+        unless ($@) {goto &CGI::Application::Plugin::ViewCode::import}
+    }
 }
 
 sub debug_report{
@@ -235,7 +245,7 @@ CGI::Application::Plugin::DebugScreen - add Debug support to CGI::Application.
 
 =head1 VERSION
 
-This documentation refers to CGI::Application::Plugin::DebugScreen version 0.03
+This documentation refers to CGI::Application::Plugin::DebugScreen version 0.04
 
 =head1 SYNOPSIS
 
@@ -253,8 +263,8 @@ When 'die' is generated by 'runmode',
  this plug-in outputs the stack trace by error_mode().
 The error cannot be caught excluding runmode.
 
-If CGI::Application::Plugin::ViewCode is used,
- this uses CGI::Application::Plugin::ViewCode. 
+This uses CGI::Application::Plugin::ViewCode
+ if a state that CGI::Application::Plugin::ViewCode can be used or used. 
 But CGI::Application::Dispatch is used,
  this not uses CGI::Application::Plugin::ViewCode.
 
@@ -274,6 +284,8 @@ L<IO::File>
 
 L<CGI::Application::Plugin::ViewCode>
 
+L<UNIVERSAL::require>
+
 =head1 BUGS AND LIMITATIONS
 
 There are no known bugs in this module.
@@ -296,6 +308,8 @@ L<IO::File>
 
 L<CGI::Application::Plugin::ViewCode>
 
+L<UNIVERSAL::require>
+
 =head1 Thanks To
 
 MATSUNO Tokuhiro (MATSUNO)
@@ -318,4 +332,3 @@ This library is free software; you can redistribute it and/or modify it
  under the same terms as Perl itself. See L<perlartistic>.
 
 =cut
-
